package com.ynet.life.base.logon;

import com.ynet.gene.core.Context;
import com.ynet.gene.core.GENEConstance;
import com.ynet.gene.session.Session;
import com.ynet.gene.session.SessionManager;
import com.ynet.life.base.LifeConstants;
import com.ynet.life.base.LifeStandard;
import com.ynet.life.exception.TranFailException;
import com.ynet.life.services.http.AsynchronousHttpService;

/* loaded from: com_ynet_life_base_logon.jar:com/ynet/life/base/logon/LifeCacheLogonManager.class */
public class LifeCacheLogonManager {
    private static final String SETTING_NAME_ENABLE_CONTROL = "enableLogonControl";
    private static final String SETTING_NAME_SERVER_ADDRESS = "serverAddress";
    private static final String SETTING_NAME_SIGNOFF_SERVLET = "signOffServlet";
    private static final String HTTP_HEAD = "http://";
    private static boolean IS_ENABLE_CONTROL = false;
    private static String SERVER_ADDRESS = "";
    private static String SIGNOFF_SERVLET = "";

    private LifeCacheLogonManager() {
    }

    public static void initialize(LifeCacheLogonEntryConfig config) throws TranFailException {
        LifeCacheLogonEntry.initialize(config);
        IS_ENABLE_CONTROL = Boolean.valueOf(LifeStandard.getSelfDefineSettingsValue(SETTING_NAME_ENABLE_CONTROL)).booleanValue();
        SERVER_ADDRESS = LifeStandard.getSelfDefineSettingsValue(SETTING_NAME_SERVER_ADDRESS);
        SIGNOFF_SERVLET = LifeStandard.getSelfDefineSettingsValue(SETTING_NAME_SIGNOFF_SERVLET);
    }

    public static void checkUserSingleLogon(String lastSessionId, SessionManager sessionManager) throws TranFailException {
        LifeCacheLogonEntry lastLogon;
        if (IS_ENABLE_CONTROL && (lastLogon = LifeCacheLogonEntry.getCurrentUserLogonEntry(lastSessionId)) != null) {
            lastLogon.getUserId();
            if (lastLogon.getSessionId() != null) {
                if (SERVER_ADDRESS.equals(lastLogon.getServerAddress())) {
                    Session lastSession = (Session) sessionManager.getSessions().get(lastLogon.getSessionId());
                    if (lastSession != null) {
                        lastSession.setAttribute("sessionKickoutFlag", LifeConstants.FIELD_SUCC_FLAG_TRUE);
                        return;
                    }
                    return;
                }
                String requestURL = HTTP_HEAD + lastLogon.getServerAddress() + SIGNOFF_SERVLET + "?" + GENEConstance.GENE_SESSION_ID_LABEL + "=" + lastLogon.getSessionId();
                new AsynchronousHttpService(requestURL).start();
            }
        }
    }

    public static boolean isLogin(Context sessionContext, SessionManager sessionManager) throws TranFailException {
        LifeLogonEntry lastLogon = LifeLogonEntry.getCurrentUserLogonEntry(sessionContext);
        if (lastLogon.getSessionId() != null && SERVER_ADDRESS.equals(lastLogon.getServerAddress()) && ((Session) sessionManager.getSessions().get(lastLogon.getSessionId())) != null) {
            return true;
        }
        return false;
    }

    public static void setServerAddress(String serverAddress) {
        SERVER_ADDRESS = serverAddress;
    }

    public static String getServerAddress() {
        return SERVER_ADDRESS;
    }
}
